pub trait FlushableBuffer {
// Required methods
fn buffer_data(&self) -> &[u8] ⓘ;
fn offset(&self) -> u64;
fn user_data(&self) -> u64;
fn submit_entry(&self) -> &SubmitQueueEntry;
}Expand description
Trait for buffers that can be submitted for flushing.
Implementors must provide the data to write, the offset, user data, and a place to store the SQE for potential re-submission.
Required Methods
Sourcefn buffer_data(&self) -> &[u8] ⓘ
fn buffer_data(&self) -> &[u8] ⓘ
Get the data to write.
Sourcefn submit_entry(&self) -> &SubmitQueueEntry
fn submit_entry(&self) -> &SubmitQueueEntry
Get the submit queue entry storage.